==> haskell-quickcheck-unicode-1.0.1.0-238-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-unicode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quickcheck-unicode
version:              1.0.1.0
visibility:           public
id:                   quickcheck-unicode-1.0.1.0-JBf49Ju05n49eV6S4cl9uS
key:                  quickcheck-unicode-1.0.1.0-JBf49Ju05n49eV6S4cl9uS
license:              BSD-2-Clause
copyright:            2014-2017 Bryan O'\''Sullivan
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/quickcheck-unicode
synopsis:
    Generator and shrink functions for testing
    Unicode-related software.

description:
    Generator and shrink functions for testing
    Unicode-related software.

category:             Testing, Text
abi:                  245cebf06751ada3dd8696f320176a97
exposed:              True
exposed-modules:      Test.QuickCheck.Unicode
import-dirs:          /usr/lib/ghc-9.2.8/site-local/quickcheck-unicode-1.0.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/quickcheck-unicode-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-unicode
hs-libraries:         HSquickcheck-unicode-1.0.1.0-JBf49Ju05n49eV6S4cl9uS
depends:
    QuickCheck-2.14.3-2FUI0ycZlrbG7BkVMiUKvc base-4.16.4.0

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-unicode/html/quickcheck-unicode.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-unicode/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-unicode-1.0.1.0-240-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-unicode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quickcheck-unicode
version:              1.0.1.0
visibility:           public
id:                   quickcheck-unicode-1.0.1.0-6qjtXmG87QTCTRI1Ik2rqe
key:                  quickcheck-unicode-1.0.1.0-6qjtXmG87QTCTRI1Ik2rqe
license:              BSD-2-Clause
copyright:            2014-2017 Bryan O'\''Sullivan
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/quickcheck-unicode
synopsis:
    Generator and shrink functions for testing
    Unicode-related software.

description:
    Generator and shrink functions for testing
    Unicode-related software.

category:             Testing, Text
abi:                  fae6ba92f5ce111cad16cdf9908035b2
exposed:              True
exposed-modules:      Test.QuickCheck.Unicode
import-dirs:          /usr/lib/ghc-9.2.8/site-local/quickcheck-unicode-1.0.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/quickcheck-unicode-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-unicode
hs-libraries:         HSquickcheck-unicode-1.0.1.0-6qjtXmG87QTCTRI1Ik2rqe
depends:
    QuickCheck-2.14.3-JblpeSTRZJp9GrWCfqywVt base-4.16.4.0

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-unicode/html/quickcheck-unicode.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-unicode/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
